/* stock_icons.c generated by valac 0.40.10, the Vala compiler
 * generated from stock_icons.vala, do not modify */

/*
 * This file is part of GNOME LaTeX.
 *
 * Copyright © 2012 Sébastien Wilmet
 *
 * GNOME LaTeX is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * GNOME LaTeX is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with GNOME LaTeX.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Sébastien Wilmet
 */
/* Add some icons to the stock icons, so it can be used e.g. in menus.*/
/* See also:*/
/* data/images/stock-icons/stock-icons.gresource.xml*/


#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>

#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _gtk_icon_set_unref0(var) ((var == NULL) ? NULL : (var = (gtk_icon_set_unref (var), NULL)))
#define __vala_GtkIconSource_free0(var) ((var == NULL) ? NULL : (var = (_vala_GtkIconSource_free (var), NULL)))



void stock_icons_register_stock_icons (void);
void stock_icons_add_theme_icon_to_stock (const gchar* icon_name);
static void _vala_GtkIconSource_free (GtkIconSource* self);


void
stock_icons_register_stock_icons (void)
{
#line 34 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent0");
#line 35 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent1");
#line 36 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent2");
#line 37 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent3");
#line 38 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent4");
#line 39 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent5");
#line 40 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent6");
#line 41 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent7");
#line 42 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent8");
#line 43 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent9");
#line 44 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent10");
#line 45 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent11");
#line 46 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent12");
#line 47 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent13");
#line 48 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent14");
#line 49 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("accent15");
#line 50 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("badbox");
#line 51 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("blackboard");
#line 52 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("bold");
#line 53 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("character-size");
#line 54 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("compile_dvi");
#line 55 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("compile_pdf");
#line 56 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("compile_ps");
#line 57 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("completion_cmd");
#line 58 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("delimiters-left");
#line 59 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("delimiters-right");
#line 60 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("gray-square");
#line 61 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("italic");
#line 62 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("list-description");
#line 63 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("list-enumerate");
#line 64 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("list-item");
#line 65 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("list-itemize");
#line 66 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("math-frac");
#line 67 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("math-nth-root");
#line 68 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("math-square-root");
#line 69 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("math-subscript");
#line 70 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("math-superscript");
#line 71 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("math");
#line 72 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent0");
#line 73 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent1");
#line 74 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent2");
#line 75 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent3");
#line 76 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent4");
#line 77 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent5");
#line 78 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent6");
#line 79 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent7");
#line 80 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent8");
#line 81 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent9");
#line 82 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathaccent10");
#line 83 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathcal");
#line 84 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("mathfrak");
#line 85 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("references");
#line 86 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("roman");
#line 87 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("sans_serif");
#line 88 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("sectioning");
#line 89 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("slanted");
#line 90 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("small_caps");
#line 91 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_arrows");
#line 92 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_delimiters");
#line 93 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_greek");
#line 94 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_misc_math");
#line 95 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_misc_text");
#line 96 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_operators");
#line 97 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("symbol_relations");
#line 98 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("table");
#line 99 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_chapter");
#line 100 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_label");
#line 101 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_paragraph");
#line 102 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_part");
#line 103 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_section");
#line 104 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_subsection");
#line 105 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_subsubsection");
#line 106 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("tree_todo");
#line 107 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("typewriter");
#line 108 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("underline");
#line 109 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("latexila-dvi");
#line 110 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("view_log");
#line 111 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("latexila-pdf");
#line 112 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	stock_icons_add_theme_icon_to_stock ("latexila-ps");
#line 208 "stock_icons.c"
}


static void
_vala_GtkIconSource_free (GtkIconSource* self)
{
#line 115 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	g_boxed_free (gtk_icon_source_get_type (), self);
#line 217 "stock_icons.c"
}


void
stock_icons_add_theme_icon_to_stock (const gchar* icon_name)
{
	GtkIconSource* icon_source = NULL;
	GtkIconSource* _tmp0_;
	GtkIconSet* icon_set = NULL;
	GtkIconSet* _tmp1_;
	GtkIconFactory* icon_factory = NULL;
	GtkIconFactory* _tmp2_;
#line 115 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	g_return_if_fail (icon_name != NULL);
#line 117 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	_tmp0_ = gtk_icon_source_new ();
#line 117 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	icon_source = _tmp0_;
#line 118 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	gtk_icon_source_set_icon_name (icon_source, icon_name);
#line 120 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	_tmp1_ = gtk_icon_set_new ();
#line 120 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	icon_set = _tmp1_;
#line 121 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	gtk_icon_set_add_source (icon_set, icon_source);
#line 123 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	_tmp2_ = gtk_icon_factory_new ();
#line 123 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	icon_factory = _tmp2_;
#line 124 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	gtk_icon_factory_add (icon_factory, icon_name, icon_set);
#line 125 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	gtk_icon_factory_add_default (icon_factory);
#line 115 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	_g_object_unref0 (icon_factory);
#line 115 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	_gtk_icon_set_unref0 (icon_set);
#line 115 "/home/seb/gnome/gnome-latex/src/stock_icons.vala"
	__vala_GtkIconSource_free0 (icon_source);
#line 258 "stock_icons.c"
}



